@@ -10,6 +10,58 @@
 
 QT_BEGIN_NAMESPACE
 
+/*!
+    \qmltype CapsuleGeometry
+    \inqmlmodule QtQuick3D.Physics.Helpers
+    \inherits Geometry
+    \since 6.4
+    \brief A geometry for generating a capsule model.
+
+    A geometry for generating a capsule model.
+*/
+
+/*! \qmlproperty bool CapsuleGeometry::enableNormals
+    \default true
+
+    Generate mesh face normals.
+*/
+
+/*! \qmlproperty bool CapsuleGeometry::enableUV
+    \default false
+
+    Generate mesh uv coordinates.
+*/
+
+/*! \qmlproperty int CapsuleGeometry::longitudes
+    \default 32
+
+    Number of longitudes, or meridians, distributed by azimuth.
+*/
+
+/*! \qmlproperty int CapsuleGeometry::latitudes
+    \default 16
+
+    Number of latitudes, distributed by inclination. Must be even.
+*/
+
+/*! \qmlproperty int CapsuleGeometry::rings
+    \default 1
+
+    Number of sections in cylinder between hemispheres.
+*/
+
+/*! \qmlproperty real CapsuleGeometry::height
+    \default 100
+
+    Height of the middle cylinder on the y axis, excluding the hemispheres.
+*/
+
+/*! \qmlproperty real CapsuleGeometry::diameter
+    \default 100
+
+    Diameter on the xz plane.
+*/
+
 CapsuleGeometry::CapsuleGeometry()
 {
     updateData();
@@ -514,8 +566,8 @@ void CapsuleGeometry::updateData()
         stride += 2 * sizeof(float);
     }
 
-    QByteArray vertexData(vertices.size() * stride, Qt::Initialization::Uninitialized);
-    QByteArray indexData(faces.size() * 3 * sizeof(quint32), Qt::Initialization::Uninitialized);
+    QByteArray vertexData(vertices.length() * stride, Qt::Initialization::Uninitialized);
+    QByteArray indexData(faces.length() * 3 * sizeof(quint32), Qt::Initialization::Uninitialized);
 
     const auto getVertexPtr = [&](const int vertexIdx) {
         return reinterpret_cast<QVector3D *>(vertexData.data() + stride * vertexIdx);
@@ -529,11 +581,11 @@ void CapsuleGeometry::updateData()
 
     uint32_t *indexPtr = reinterpret_cast<uint32_t *>(indexData.data());
 
-    for (qsizetype i = 0; i < vertices.size(); i++) {
+    for (qsizetype i = 0; i < vertices.length(); i++) {
         *getVertexPtr(i) = vertices[i];
     }
 
-    for (qsizetype i = 0; i < faces.size(); i++) {
+    for (qsizetype i = 0; i < faces.length(); i++) {
         const auto vertexIndices =
                 std::array<uint32_t, 3> { faces[i][0].vertexIdx, faces[i][1].vertexIdx,
                                           faces[i][2].vertexIdx };
@@ -580,8 +632,8 @@ void CapsuleGeometry::updateData()
     setVertexData(vertexData);
     setIndexData(indexData);
 
-    setBounds(QVector3D(-radius, -radius - 0.5f * m_height, -radius),
-              QVector3D(radius, radius + 0.5f * m_height, radius));
+    setBounds(QVector3D(-radius - 0.5f * m_height, -radius, -radius),
+              QVector3D(radius + 0.5f * m_height, radius, radius));
 }
 
 QT_END_NAMESPACE
