@@ -26,6 +26,8 @@ class QAbstractPhysicsBody : public QAbstractPhysicsNode
     Q_OBJECT
     Q_PROPERTY(QPhysicsMaterial *physicsMaterial READ physicsMaterial WRITE setPhysicsMaterial
                        NOTIFY physicsMaterialChanged)
+    Q_PROPERTY(bool simulationEnabled READ simulationEnabled WRITE setSimulationEnabled NOTIFY
+                       simulationEnabledChanged)
     QML_NAMED_ELEMENT(PhysicsBody)
     QML_UNCREATABLE("abstract interface")
 
@@ -33,11 +35,17 @@ public:
     QAbstractPhysicsBody();
     QPhysicsMaterial *physicsMaterial() const;
     void setPhysicsMaterial(QPhysicsMaterial *newPhysicsMaterial);
+
+    Q_REVISION(6, 7) bool simulationEnabled() const;
+    Q_REVISION(6, 7) void setSimulationEnabled(bool newSimulationEnabled);
+
 Q_SIGNALS:
     void physicsMaterialChanged();
+    void simulationEnabledChanged();
 
 private:
     QPhysicsMaterial *m_physicsMaterial = nullptr;
+    bool m_simulationEnabled = true;
 };
 
 QT_END_NAMESPACE
